@@ -1,6 +1,6 @@
-package Pcore::SQLite v0.3.3;
+package Pcore::SQLite v0.3.4;
 
-use Pcore qw[-class];
+use Pcore -class;
 
 1;
 __END__
